@@ -134,8 +134,7 @@ void LatexStyleParser::run()
 		QStringList included = results.filter(QRegExp("#include:.+"));
 		foreach (QString elem, included) {
 			elem = elem.mid(9);
-			QString fn = findResourceFile("completion/" + elem + ".cwl", false, QStringList(baseDir));
-			if (fn.isEmpty()) {
+			if (!QFileInfo("cwl:" + elem + ".cwl").exists()) {
 				QString hlp = kpsewhich(elem + ".sty");
 				if (!hlp.isEmpty()) {
 					if (!topPackage.isEmpty())
@@ -150,7 +149,7 @@ void LatexStyleParser::run()
 			QFileInfo info(fn);
 			QString baseName = info.completeBaseName();
 			if (!baseName.isEmpty()) {
-				QFile data(baseDir + "/" + baseName + ".cwl");
+				QFile data(joinPath(baseDir, "completion/autogenerated", baseName + ".cwl"));
 				if (data.open(QFile::WriteOnly | QFile::Truncate)) {
 					QTextStream out(&data);
 					out << "# autogenerated by txs\n";
