@@ -363,6 +363,16 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		    m_disableAccentHack=disable;
 		}
 
+        void addMark(int pos,QColor color,QString type="");
+        void addMarkDelayed(int pos, QColor color, QString type);
+        void addMark(QDocumentLineHandle *dlh, QColor color, QString type="");
+        void addMarkRange(int start,int end,QColor color,QString type="");
+        void removeMark(int pos, QString type="");
+        void removeMark(QDocumentLineHandle *dlh,QString type="");
+        void removeMark(QString type);
+        void removeAllMarks();
+        void paintMarks();
+
 	public slots:
 		void undo();
 		void redo();
@@ -408,6 +418,7 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		void setWrapAfterNumChars(int numChars);
 protected:
 		void setWrapLineWidth(int l);
+		bool writeToFile(const QString &filename, const QByteArray &data);
 public:		
 		virtual void save();
 		void save(const QString& filename);
@@ -481,6 +492,7 @@ public slots:
 		
 		void contentModified(bool y);
 		void titleChanged(const QString& title);
+		void focusReceived();
 		
 		void textEdited(QKeyEvent *e);
 		void cursorPositionChanged();
@@ -603,6 +615,7 @@ public slots:
 
 		Q_INVOKABLE void clearCursorMirrors();
 		Q_INVOKABLE void addCursorMirror(const QDocumentCursor& c);
+		Q_INVOKABLE void cursorMirrorsRemoveSelectedText();
 
 		void setCursorBold(bool bold);
 
