@@ -1,7 +1,20 @@
 #include "syntaxcheck.h"
 #include "latexdocument.h"
 #include "tablemanipulation.h"
+/*! \class SyntaxCheck
+ *
+ * asynchrnous thread which checks latex syntax of the text lines
+ * It gets the linehandle via a queue, together with a ticket number.
+ * The ticket number is increased with every change of the text of a line, thus it can be determined of the processed handle is still unchanged and can be discarded otherwise.
+ * Syntaxinformation are stated via markers on the text.
+ * Furthermore environment information, especially tabular information are stored in "cookies" as they are needed in subsequent lines.
+ *
+ */
 
+/*!
+ * \brief contructor
+ * \param parent
+ */
 SyntaxCheck::SyntaxCheck(QObject *parent) :
 	SafeThread(parent), syntaxErrorFormat(-1), ltxCommands(0), newLtxCommandsAvailable(false)
 {
@@ -13,11 +26,21 @@ SyntaxCheck::SyntaxCheck(QObject *parent) :
 	//mLtxCommandLock.unlock();
 }
 
+/*!
+ * \brief set the errorformat for syntax errors
+ * \param errFormat
+ */
 void SyntaxCheck::setErrFormat(int errFormat)
 {
 	syntaxErrorFormat = errFormat;
 }
-
+/*!
+ * \brief add line to queue
+ * \param dlh linehandle
+ * \param previous linehandle of previous line
+ * \param stack tokenstack at line start (for handling open arguments of previous commands)
+ * \param clearOverlay clear syntaxcheck overlay
+ */
 void SyntaxCheck::putLine(QDocumentLineHandle *dlh, StackEnvironment previous, TokenStack stack, bool clearOverlay)
 {
 	REQUIRE(dlh);
@@ -37,13 +60,18 @@ void SyntaxCheck::putLine(QDocumentLineHandle *dlh, StackEnvironment previous, T
 	//mResultLock.lock(); not possible under windows
 	mLinesAvailable.release();
 }
-
+/*!
+ * \brief stop processing syntax checks
+ */
 void SyntaxCheck::stop()
 {
 	stopped = true;
 	mLinesAvailable.release();
 }
 
+/*!
+ * \brief actual thread loop
+ */
 void SyntaxCheck::run()
 {
 	ltxCommands = new LatexParser();
@@ -114,6 +142,18 @@ void SyntaxCheck::run()
 	ltxCommands = 0;
 }
 
+/*!
+ * \brief check one line
+ *
+ * Checks one line. Context information needs to be given by newRanges,activeEnv,dlh and ticket.
+ * This method is obsolete as the new system relies on tokens.
+ * \warning obsolete method
+ * \param line text of line as string
+ * \param newRanges will return the result as ranges
+ * \param activeEnv environmwent context
+ * \param dlh linehandle
+ * \param ticket ticket number for current processed line
+ */
 void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnvironment &activeEnv, QDocumentLineHandle *dlh, int ticket)
 {
 	// do syntax check on that line
@@ -236,6 +276,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			if (ltxCommands->mathStartCommands.contains(word) && (activeEnv.isEmpty() || activeEnv.top().name != "math")) {
 				Environment env;
 				env.name = "math";
+                env.origName=word;
 				env.id = 1; // to be changed
 				env.dlh = dlh;
 				env.ticket = ticket;
@@ -243,7 +284,11 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				continue;
 			}
 			if (ltxCommands->mathStopCommands.contains(word) && !activeEnv.isEmpty() && activeEnv.top().name == "math") {
-				activeEnv.pop();
+                int i=ltxCommands->mathStopCommands.indexOf(word);
+                QString txt=ltxCommands->mathStartCommands.value(i);
+                if(activeEnv.top().origName==txt){
+                    activeEnv.pop();
+                }// ignore mismatching mathstop commands
 				continue;
 			}
 			if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
@@ -400,7 +445,14 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 		}
 	}
 }
-
+/*!
+ * \brief get error description for syntax error in line 'dlh' at column 'pos'
+ * \param dlh linehandle
+ * \param pos column
+ * \param previous environment stack at start of line
+ * \param stack tokenstack at start of line
+ * \return error description
+ */
 QString SyntaxCheck::getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironment previous, TokenStack stack)
 {
 	// do syntax check
@@ -438,6 +490,10 @@ QString SyntaxCheck::getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironm
 	         << tr("\\\\ missing") << tr("closing environment which has not been opened") << tr("environment not closed") << tr("unrecognized key in key option") << tr("unrecognized value in key option");
 	return messages.value(int(result), tr("unknown"));
 }
+/*!
+ * \brief set latex commands which are referenced for syntax checking
+ * \param cmds
+ */
 void SyntaxCheck::setLtxCommands(const LatexParser &cmds)
 {
 	if (stopped) return;
@@ -446,19 +502,30 @@ void SyntaxCheck::setLtxCommands(const LatexParser &cmds)
 	newLtxCommands = cmds;
 	mLtxCommandLock.unlock();
 }
-
+/*!
+ * \brief wait for queue to be empty. Used for self-test only.
+ */
 void SyntaxCheck::waitForQueueProcess()
 {
 	while (!crashed && mLinesAvailable.available() > 0) {
 		wait(1);
 	}
 }
-
+/*!
+ * \brief check if queue is empty. Used for self-test only.
+ * \return queue is not empty
+ */
 bool SyntaxCheck::queuedLines()
 {
 	return mLinesAvailable.available() > 0;
 }
-
+/*!
+ * \brief check if top-most environment in 'envs' is `name`
+ * \param name environment name which is checked
+ * \param envs stack of environments
+ * \param id check for `id` of the environment, <0 means check is disabled
+ * \return environment id or 0
+ */
 int SyntaxCheck::topEnv(const QString &name, const StackEnvironment &envs, const int id)
 {
 	if (envs.isEmpty())
@@ -478,7 +545,14 @@ int SyntaxCheck::topEnv(const QString &name, const StackEnvironment &envs, const
 	}
 	return 0;
 }
-
+/*!
+ * \brief check if the environment stack contains a environment with name `name`
+ * \param parser reference to LatexParser. It is used to access environment aliases, e.g. equation is also a math environment
+ * \param name name of the checked environment
+ * \param envs stack of environements
+ * \param id if >=0 check if the env has the given id.
+ * \return environment id of  found env otherwise 0
+ */
 int SyntaxCheck::containsEnv(const LatexParser &parser, const QString &name, const StackEnvironment &envs, const int id)
 {
 	for (int i = envs.size() - 1; i > -1; --i) {
@@ -497,7 +571,12 @@ int SyntaxCheck::containsEnv(const LatexParser &parser, const QString &name, con
 	}
 	return 0;
 }
-
+/*!
+ * \brief check if the command is valid in the environment stack
+ * \param cmd name of command
+ * \param envs environment stack
+ * \return is valid
+ */
 bool SyntaxCheck::checkCommand(const QString &cmd, const StackEnvironment &envs)
 {
 	for (int i = 0; i < envs.size(); ++i) {
@@ -514,7 +593,12 @@ bool SyntaxCheck::checkCommand(const QString &cmd, const StackEnvironment &envs)
 	}
 	return false;
 }
-
+/*!
+ * \brief compare two environment stacks
+ * \param env1
+ * \param env2
+ * \return are equal
+ */
 bool SyntaxCheck::equalEnvStack(StackEnvironment env1, StackEnvironment env2)
 {
 	if (env1.isEmpty() || env2.isEmpty())
@@ -527,7 +611,12 @@ bool SyntaxCheck::equalEnvStack(StackEnvironment env1, StackEnvironment env2)
 	}
 	return true;
 }
-
+/*!
+ * \brief mark environment start
+ *
+ * This function is used to mark unclosed environment,i.e. environments which are unclosed at the end of the text
+ * \param env used environment
+ */
 void SyntaxCheck::markUnclosedEnv(Environment env)
 {
 	QDocumentLineHandle *dlh = env.dlh;
@@ -553,7 +642,11 @@ void SyntaxCheck::markUnclosedEnv(Environment env)
 	}
 	dlh->unlock();
 }
-
+/*!
+ * \brief check if the tokenstack contains a definition-token
+ * \param stack tokenstack
+ * \return contains a definition
+ */
 bool SyntaxCheck::stackContainsDefinition(const TokenStack &stack) const
 {
 	for (int i = 0; i < stack.size(); i++) {
@@ -562,6 +655,19 @@ bool SyntaxCheck::stackContainsDefinition(const TokenStack &stack) const
 	}
 	return false;
 }
+/*!
+ * \brief check one line
+ *
+ * Checks one line. Context information needs to be given by newRanges,activeEnv,dlh and ticket.
+ * This method is obsolete as the new system relies on tokens.
+ * \param line text of line as string
+ * \param newRanges will return the result as ranges
+ * \param activeEnv environment context
+ * \param dlh linehandle
+ * \param tl tokenlist of line
+ * \param stack token stack at start of line
+ * \param ticket ticket number for current processed line
+ */
 
 void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnvironment &activeEnv, QDocumentLineHandle *dlh, TokenList tl, TokenStack stack, int ticket)
 {
@@ -611,6 +717,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			if (ltxCommands->mathStartCommands.contains(word) && (activeEnv.isEmpty() || activeEnv.top().name != "math")) {
 				Environment env;
 				env.name = "math";
+                env.origName=word;
 				env.id = 1; // to be changed
 				env.dlh = dlh;
 				env.ticket = ticket;
@@ -618,7 +725,11 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				continue;
 			}
 			if (ltxCommands->mathStopCommands.contains(word) && !activeEnv.isEmpty() && activeEnv.top().name == "math") {
-				activeEnv.pop();
+                int i=ltxCommands->mathStopCommands.indexOf(word);
+                QString txt=ltxCommands->mathStartCommands.value(i);
+                if(activeEnv.top().origName==txt){
+                    activeEnv.pop();
+                }// ignore mismatching mathstop commands
 				continue;
 			}
 			if (word == "\\\\" && topEnv("tabular", activeEnv) != 0) {
@@ -739,6 +850,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			if (ltxCommands->mathStartCommands.contains(word) && (activeEnv.isEmpty() || activeEnv.top().name != "math")) {
 				Environment env;
 				env.name = "math";
+                env.origName=word;
 				env.id = 1; // to be changed
 				env.dlh = dlh;
 				env.ticket = ticket;
@@ -746,7 +858,11 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				continue;
 			}
 			if (ltxCommands->mathStopCommands.contains(word) && !activeEnv.isEmpty() && activeEnv.top().name == "math") {
-				activeEnv.pop();
+                int i=ltxCommands->mathStopCommands.indexOf(word);
+                QString txt=ltxCommands->mathStartCommands.value(i);
+                if(activeEnv.top().origName==txt){
+                    activeEnv.pop();
+                }// ignore mismatching mathstop commands
 				continue;
 			}
 
@@ -828,7 +944,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
         }
 		if (tk.type == Tokens::keyVal_key) {
 			// special treatment for key val checking
-			QString command = getCommandFromToken(tk);
+			QString command = tk.optionalCommandName;
 			QString value = line.mid(tk.start, tk.length);
 
 			// search stored keyvals
